@@ -732,7 +732,7 @@ def GraEstModels(a,b,c,d,e,f,g,h):
     axs[1,1].set_ylim(ymin,ymax)
     axs[1,1].set_title('Extreme Gradient Boosting', size= 18)
 
-    plt.tight_layout();
+    plt.show()
 
     ##### Error1 ####
 
@@ -1313,7 +1313,7 @@ def Rend_Est_ML(reml2):
     axs[1,1].set_title('Extreme Gradient Boosting')
     axs[1,1].grid(True)
 
-    plt.tight_layout()
+    plt.show()
 def Error_AVM_vs_ML(reml2):
     real=reml2['valor']
     estimadoavm=reml2['Estimación AVM']
